==> defi_state_querier-0.4.14-py3-none-any.whl: defi_services/services/lending/lending_info/polygon/compound_v3_polygon.py <==
COMPOUND_V3_POLYGON = {
    "name": "Compound V3 Lending Pool",
    "rewardToken": "0x8505b9d2254a7ae468c0e9dd10ccea3a837aef5c",
    "rewardAddress": "0x45939657d1ca34a8fa39a924b71d28fe8431e581",
    "factoryAddress": "0x2f9e3953b2ef89fa265f2a32ed9f80d00229125b",
    "poolToken": "0x8505b9d2254a7ae468c0e9dd10ccea3a837aef5c",
    "type": "LENDING_POOL",
    "forked": "compound-v3",
    "reservesList": {
        "0x2791bca1f2de4661ed88a30c99a7a9449aa84174": {
            "comet": "0xf25212e676d1f7f89cd72ffee66158f541246445",
            "assets": {
                "0x7ceb23fd6bc0add59e62ac25578270cff1b9f619": {
                    "priceFeed": "0xf9680d99d6c9589e2a93a78a04a279e509205945",
                    "loanToValue": 0.775,
                    "liquidationThreshold": 0.825
                },
                "0x1bfd67037b42cf73acf2047067bd4f2c47d9bfd6": {
                    "priceFeed": "0xde31f8bfbd8c84b5360cfacca3539b938dd78ae6",
                    "loanToValue": 0.7,
                    "liquidationThreshold": 0.75
                },
                "0x0d500b1d8e8ef31e21c99d1db9a6444d3adf1270": {
                    "priceFeed": "0xab594600376ec9fd91f8e885dadf0ce036862de0",
                    "loanToValue": 0.65,
                    "liquidationThreshold": 0.7
                },
                "0xfa68fb4628dff1028cfec22b4162fccd0d45efb6": {
                    "priceFeed": "0x5d37e4b374e6907de8fc7fb33ee3b0af403c7403",
                    "loanToValue": 0.55,
                    "liquidationThreshold": 0.6
                },
                "0x3a58a54c066fdc0f2d55fc9c89f0415c92ebf3c4": {
                    "priceFeed": "0x97371df4492605486e23da797fa68e55fc38a13f",
                    "loanToValue": 0.6,
                    "liquidationThreshold": 0.65
                }
            }
        }
    }
}

==> defi_state_querier-0.5.29-py3-none-any.whl: defi_services/services/lending/lending_info/polygon/compound_v3_polygon.py <==
COMPOUND_V3_POLYGON = {
    "name": "Compound V3 Lending Pool",
    "rewardToken": "0x8505b9d2254a7ae468c0e9dd10ccea3a837aef5c",
    "rewardAddress": "0x45939657d1ca34a8fa39a924b71d28fe8431e581",
    "factoryAddress": "0x2f9e3953b2ef89fa265f2a32ed9f80d00229125b",
    "poolToken": "0x8505b9d2254a7ae468c0e9dd10ccea3a837aef5c",
    "type": "LENDING_POOL",
    "forked": "compound-v3",
    "reservesList": {
        "0x2791bca1f2de4661ed88a30c99a7a9449aa84174": {
            "comet": "0xf25212e676d1f7f89cd72ffee66158f541246445",
            "assets": {
                "0x7ceb23fd6bc0add59e62ac25578270cff1b9f619": {
                    "priceFeed": "0xf9680d99d6c9589e2a93a78a04a279e509205945",
                    "loanToValue": 0.8,
                    "liquidationThreshold": 0.85
                },
                "0x1bfd67037b42cf73acf2047067bd4f2c47d9bfd6": {
                    "priceFeed": "0xde31f8bfbd8c84b5360cfacca3539b938dd78ae6",
                    "loanToValue": 0.75,
                    "liquidationThreshold": 0.85
                },
                "0x0d500b1d8e8ef31e21c99d1db9a6444d3adf1270": {
                    "priceFeed": "0xab594600376ec9fd91f8e885dadf0ce036862de0",
                    "loanToValue": 0.65,
                    "liquidationThreshold": 0.8
                },
                "0xfa68fb4628dff1028cfec22b4162fccd0d45efb6": {
                    "priceFeed": "0x5d37e4b374e6907de8fc7fb33ee3b0af403c7403",
                    "loanToValue": 0.55,
                    "liquidationThreshold": 0.6
                },
                "0x3a58a54c066fdc0f2d55fc9c89f0415c92ebf3c4": {
                    "priceFeed": "0x97371df4492605486e23da797fa68e55fc38a13f",
                    "loanToValue": 0.6,
                    "liquidationThreshold": 0.65
                }
            }
        },
        "0xc2132d05d31c914a87c6611c10748aeb04b58e8f": {
            "comet": "0xaeb318360f27748acb200ce616e389a6c9409a07",
            "assets": {
                "0x0d500b1d8e8ef31e21c99d1db9a6444d3adf1270": {
                    "priceFeed": "0xab594600376ec9fd91f8e885dadf0ce036862de0",
                    "loanToValue": 0.65,
                    "liquidationThreshold": 0.8
                },
                "0x7ceb23fd6bc0add59e62ac25578270cff1b9f619": {
                    "priceFeed": "0xf9680d99d6c9589e2a93a78a04a279e509205945",
                    "loanToValue": 0.8,
                    "liquidationThreshold": 0.85
                },
                "0xfa68fb4628dff1028cfec22b4162fccd0d45efb6": {
                    "priceFeed": "0x5d37e4b374e6907de8fc7fb33ee3b0af403c7403",
                    "loanToValue": 0.6,
                    "liquidationThreshold": 0.7
                },
                "0x3a58a54c066fdc0f2d55fc9c89f0415c92ebf3c4": {
                    "priceFeed": "0x97371df4492605486e23da797fa68e55fc38a13f",
                    "loanToValue": 0.6,
                    "liquidationThreshold": 0.7
                },
                "0x1bfd67037b42cf73acf2047067bd4f2c47d9bfd6": {
                    "priceFeed": "0xde31f8bfbd8c84b5360cfacca3539b938dd78ae6",
                    "loanToValue": 0.75,
                    "liquidationThreshold": 0.85
                }
            }
        }
    }
}
